@@ -3,7 +3,7 @@
   @file ic-api.c
   
   osso-ic-oss Internet Connectivity library
-  Copyright (C) 2005 Nokia Corporation
+  Copyright (C) 2005,2006 Nokia Corporation. All rights reserved.
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Lesser General Public License version 2.1 as
@@ -413,6 +413,7 @@ GSList *osso_iap_get_configured_iaps(void)
 {
 	GConfClient *client;
 	GSList *list, *entry;
+	GSList *newl = NULL;
 
 	client = gconf_client_get_default();
 	if (client == NULL)
@@ -421,17 +422,23 @@ GSList *osso_iap_get_configured_iaps(void)
 	list = gconf_client_all_dirs(client, ICD_GCONF_PATH, NULL);
 	g_object_unref(client);
 
-	/* GConf return absolute directory names, so we just
-	 * rewrite the strings to be relative directory names */
+	/* GConf returns absolute directory names, so we just
+	 * return the relative directory names */
 	for (entry = list; entry; entry = entry->next) {
 		gchar *tmp;
 
 		tmp = gconf_unescape_key(strrchr(entry->data, '/')+1, -1);
 		g_free(entry->data);
-		entry->data = tmp;
+		if (tmp != NULL &&
+		    strncmp (tmp, "[EasyWLAN", 9))
+			newl = g_slist_prepend (newl, tmp);
+		else
+			g_free(tmp);
 	}
+	g_slist_free (list);
+	newl = g_slist_reverse (newl);
 
-	return list;
+	return newl;
 }
 
 static DBusMessage *send_message_blocking(DBusMessage *msg,
